package com.tencent.tmgp.yybtestsdk;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.tencent.ysdk.api.YSDKApi;
import com.tencent.ysdk.framework.common.eFlag;
import com.tencent.ysdk.framework.common.ePlatform;
import com.tencent.ysdk.module.user.UserApi;
import com.tencent.ysdk.module.user.UserListener;
import com.tencent.ysdk.module.user.UserLoginRet;
import com.tencent.ysdk.module.user.UserRelationRet;
import com.tencent.ysdk.module.user.WakeupRet;

public class MainActivity extends Activity {
    private Button tv;
    private LoginManager loginManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        tv = findViewById(R.id.text);

        //YSDK加载逻辑
        YSDKApi.onCreate(this);
        YSDKApi.handleIntent(this.getIntent());
        initYSDK();
    }

    private void initYSDK() {
        //注册用户事件回调
        loginManager = new LoginManager();
        YSDKApi.setUserListener(loginManager);

        //判断用户是否第一次进入游戏
        //如果不是第一次登录，YSDK将自动登录游戏并通过LoginManager.OnLoginNotify回调登录结果给游戏
        if (loginManager.needFirstLogin()) {
            loginManager.letUserLogout();
        }

    }

    @Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        YSDKApi.handleIntent(this.getIntent());
    }

    @Override
    protected void onPause() {
        YSDKApi.onPause(this);
        super.onPause();
    }

    @Override
    protected void onRestart() {
        super.onRestart();
        YSDKApi.onRestart(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        YSDKApi.onResume(this);
    }

    @Override
    protected void onStop() {
        super.onStop();
        YSDKApi.onStop(this);
    }

    @Override
    protected void onDestroy() {
        YSDKApi.onDestroy(this);
        super.onDestroy();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        YSDKApi.onActivityResult(requestCode, resultCode, data);
    }

    /**
     * 此Manager类处理登录相关界面展示
     */
    class LoginManager implements UserListener {

        public boolean needFirstLogin() {
            UserLoginRet ret = UserApi.getInstance().getLoginRecord();
            return ret.platform == ePlatform.None.val();
        }

        /**
         * 登录结果回调函数
         * @param ret
         */
        @Override
        public void OnLoginNotify(UserLoginRet ret) {
            Log.i("YSDK_Log", ret.toString());
            switch (ret.flag) {
                case eFlag.Succ:
                    letUserLogin(ret);
                    break;
                // 游戏逻辑，对登录失败情况分别进行处理
                case eFlag.QQ_UserCancel:
                    Log.i("YSDK_Log", "用户取消授权，请重试");
                    letUserLogout();
                    break;
                case eFlag.QQ_LoginFail:
                    Log.i("YSDK_Log", "QQ登录失败，请重试");
                    letUserLogout();
                    break;
                case eFlag.QQ_NetworkErr:
                    Log.i("YSDK_Log", "QQ登录异常，请重试");
                    letUserLogout();
                    break;
                case eFlag.QQ_NotInstall:
                    Log.i("YSDK_Log", "手机未安装手Q，请安装后重试");
                    letUserLogout();
                    break;
                case eFlag.QQ_NotSupportApi:
                    Log.i("YSDK_Log", "手机手Q版本太低，请升级后重试");
                    letUserLogout();
                    break;
                case eFlag.Login_TokenInvalid:
                    Log.i("YSDK_Log", "您尚未登录或者之前的登录已过期，请重试");
                    letUserLogout();
                    break;
                case eFlag.Login_NotRegisterRealName:
                    Log.i("YSDK_Log", "您的账号没有进行实名认证，请实名认证后重试");
                    letUserLogout();
                    break;
                default:

                    letUserLogout();
                    break;
            }
        }

        @Override
        public void OnWakeupNotify(WakeupRet wakeupRet) {
            Log.i("YSDK_Log", wakeupRet.toString());
        }

        @Override
        public void OnRelationNotify(UserRelationRet userRelationRet) {
            Log.i("YSDK_Log", userRelationRet.toString());
        }


        /**
         * 游戏进入登录后页面
         *
         * @param ret
         */
        public void letUserLogin(UserLoginRet ret) {
            Log.i("YSDK_Log", "游戏已登录");
            Log.i("YSDK_Log", ret.toString());
            setButtonToLogin();
        }

        /**
         * 游戏进入登录前界面
         */

        public void letUserLogout() {
            Log.i("YSDK_Log", "游戏已登出");
            YSDKApi.logout();
            setButtonToLogout();
        }

        /**
         * 把按钮状态设置为未登录状态
         */
        private void setButtonToLogout() {
            tv.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    //点击登录
                    UserApi.getInstance().login(ePlatform.QQ);
                }
            });
            tv.setText("点击登录QQ");
        }

        /**
         * 把按钮状态设置为已登录状态
         */
        private void setButtonToLogin() {
            tv.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    letUserLogout();
                }
            });
            tv.setText("登出");
        }


    }

    /**
     * 彻底退出APP
     */
    @Override
    public void onBackPressed() {
        System.exit(0);
    }
}
